import React from 'react';
import spinner from './Spinner.svg';

class LocationDropdown extends React.Component {
    constructor(props) {
        super(props);
        this.state = {
            locationsData: [],
            selectedCountry: '',
            selectedState: '',
            selectedCity: '',
            loadingCountry: false,
          
        };
    }
    
    componentDidMount() {
        this.setState({ loadingCountry: true });
        fetch('api_path/locations.php')
            .then(response => response.json())
            .then(data => {
                this.setState({ locationsData: data });
            })
            .catch(error => {
                console.error('Error fetching data:', error);
            })
            .finally(() => {
                this.setState({ loadingCountry: false });
            });
    }
    handleCountryChange = (event) => {
        const selectedCountry = event.target.value;
        this.setState({
            selectedCountry,
            selectedState: '',
            selectedCity: '',
        });
    };
    
    handleStateChange = (event) => {
        const selectedState = event.target.value;
        this.setState({
            selectedState,
        });
    };
    handleCityChange = (event) => {
        const selectedCity = event.target.value;
        this.setState({
            selectedCity,
        });
    };
    
    
    
    render() {
        const { selectedCountry, selectedState, selectedCity, locationsData, loadingCountry} = this.state;
    
        const countryOptions = locationsData.map(country => (
            <option key={country.name} value={country.name}>
                {country.name}
            </option>
        ));
    
        const selectedCountryData = locationsData.find(country => country.name === selectedCountry);
        const stateOptions = selectedCountryData
            ? selectedCountryData.states.map(state => (
                 <option key={state.name} value={state.name}>
                      {state.name}
                 </option>
              ))
            : [];
    
        const selectedStateData = selectedCountryData
            ? selectedCountryData.states.find(state => state.name === selectedState)
            : null;
        const cityOptions = selectedStateData
            ? selectedStateData.cities.map(city => (
                 <option key={city} value={city}>
                      {city}
                 </option>
              ))
            : [];
    
            const countrySpinner = loadingCountry ? <img className='spinner' src={spinner} alt="Loading..." /> : null;
    
            return (
                <div className='title'>
                    <div className='center-content'>
                        <div id='demo-content'>
                            <div className='form'>
                                <label htmlFor="country">Country:</label>
                                <div className="spinner-wrapper">{countrySpinner}</div>
                                <select value={selectedCountry} onChange={this.handleCountryChange}>
                                    <option value="">Select Country</option>
                                    {countryOptions}
                                </select>
        
                                <label htmlFor="state">State:</label>
                                <select value={selectedState} onChange={this.handleStateChange}>
                                    <option value="">Select State</option>
                                    {stateOptions}
                                </select>
        
                                <label htmlFor="city">City:</label>
                                <select value={selectedCity} onChange={this.handleCityChange}>
                                    <option value="">Select City</option>
                                    {cityOptions}
                                </select>
                            </div>
                        </div>
                    </div>
                </div>
            );
        }
    }
    
    export default LocationDropdown;